<?php
/**
 * Main application class
 *
 * @package wp-tube-profit-wiz
 * @author Chris Jenkins
 * @link http://pluginsforyou.com/
 */

//
//Include all function files
require_once( IPMTUBE_LIB . '/config.php' );
require_once( IPMTUBE_LIB . '/setting.php' );
require_once( IPMTUBE_LIB . '/model.php' );
require_once( IPMTUBE_LIB . '/font.php' );
require_once( IPMTUBE_LIB . '/form.php' );
require_once( IPMTUBE_LIB . '/db.php' );
require_once( IPMTUBE_APP . '/controller.php' );
require_once( IPMTUBE_APP . '/viewer.php' );

if ( ! class_exists( 'IPMTube_App' ))
{
    class IPMTube_App
    {
        //{{ run

        /**
         * Run all functions
         *
         * @return void
         */
        public static function run()
        {
            $hook = sanitize_title( IPMTUBE_TITLE );

            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );

            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

            //
            //Admin init
            add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

            //
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

            /**
             * Shortcode setup
             */
            // Add generator shortcode button
            add_action( 'init', array( __CLASS__, 'addShortcodeEditorButton' ), 100 );
            // Add pop up content
            add_filter( 'the_editor', array( __CLASS__, 'shortcodeEditorFilter' ) );
            add_action( 'admin_footer', array( __CLASS__, 'addShortcodeForm' ) );
            //Add Shortcode
            add_shortcode( 'wp_tube_profit_wiz', array( __CLASS__, 'shortcode' ) );

            //
            //Add css
            add_action( 'admin_print_styles-toplevel_page_' . IPMTUBE_PAGENAME, array( __CLASS__, 'adminStyle' ), 1100 );
            add_action( 'admin_print_styles-'.$hook.'_page_' . IPMTUBE_PAGENAME . '-addnew', array( __CLASS__, 'adminStyle' ), 1100 );
            add_action( 'admin_print_styles', array( __CLASS__, 'adminGlobalStyle' ), 1000 );

            //
            //Add javascript
            add_action( 'admin_print_scripts-toplevel_page_' . IPMTUBE_PAGENAME, array( __CLASS__, 'adminScript' ), 1100 );
            add_action( 'admin_print_scripts-'.$hook.'_page_' . IPMTUBE_PAGENAME . '-addnew', array( __CLASS__, 'adminScript' ), 1100 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'adminGlobalScript' ), 1000 );

            //Front style & script
            add_action('wp_head', array( __CLASS__, 'publicStyle' ) );
            add_action('wp_footer', array( __CLASS__, 'publicFooterScript' ) );

            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'publicScript' ), 10 );
            }
        }

        //}}
        //{{ install

        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Install DB
            $db = new IPMTube_Db();
            $db->install();
        }

        //}}
        //{{ updateDb

        /**
         * Update Db
         *
         * @return void
         */
        public static function updateDb()
        {
            $db = new IPMTube_Db();
            $db->update();
        }

        //}}
        //{{ addAdminMenu

        /**
         * Add admin menu
         *
         * @return void
         */
        public static function addAdminMenu()
        {
            add_menu_page(
                IPMTUBE_TITLE,
                IPMTUBE_TITLE,
                'edit_posts',
                IPMTUBE_PAGENAME,
                array( __CLASS__, 'dashboard' ),
                'dashicons-format-video',
                30
            );
            add_submenu_page(
                IPMTUBE_PAGENAME,
                __( 'All Videos', IPMTUBE_SLUG ),
                __( 'All Videos', IPMTUBE_SLUG ),
                'edit_posts',
                IPMTUBE_PAGENAME,
                array( __CLASS__, 'dashboard' )
            );
            add_submenu_page(
                IPMTUBE_PAGENAME,
                __( 'Add New', IPMTUBE_SLUG ),
                __( 'Add New', IPMTUBE_SLUG ),
                'edit_posts',
                IPMTUBE_PAGENAME . '-addnew',
                array( __CLASS__, 'addnew' )
            );
        }

        //}}
        //{{ adminInit

        /**
         * Admin init
         *
         * @return void
         */
        public static function adminInit()
        {
            /**
             * Ajax handler
             **/
            $controller = new IPMTube_Controller();
            $controller->ajax();
        }

        //}}
        //{{ dashboard

        /**
         * Render admin dashboard page
         *
         * @return void
         */
        public static function dashboard()
        {
            $viewer = new IPMTube_Viewer();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $viewer->edit();
            } else {
                $viewer->dashboard();
            }
        }

        //}}
        //{{ addnew

        /**
         * Render add new page
         *
         * @return void
         */
        public static function addnew()
        {
            $viewer = new IPMTube_Viewer();
            $viewer->addnew();
        }

        //}}
        //{{ addShortcodeEditorButton

        /**
         * Add shortcode button in content editor
         *
         * @return void
         */
        public static function addShortcodeEditorButton()
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( __CLASS__, 'addTinymcePlugin' ));
                add_filter( 'mce_buttons', array( __CLASS__, 'registerTinymceButton' ));
            }
        }

        //}}
        //{{ addTinymcePlugin

        /**
         * Add tinyMce plugin
         *
         * @return void
         */
        public static function addTinymcePlugin( $plugin_array )
        {
            $plugin_array['ipmtube_shortcode'] = IPMTUBE_BASE_URL . '/assets/js/editor-plugin.js';
            return $plugin_array;
        }

        //}}
        //{{ registerTinymceButton

        /**
         * Add tinyMce button
         *
         * @return void
         */
        public static function registerTinymceButton( $buttons )
        {
            array_push($buttons, "|", "ipmtube_shortcode");
            return $buttons;
        }

        //}}
        //{{ shortcodeEditorFilter

        /**
         * The editor filter
         *
         * @param  string $content
         * @return string
         */
        public static function shortcodeEditorFilter( $content )
        {
            global $ipmtube_useEditor;

            $ipmtube_useEditor = true;
            return $content;
        }

        //}}
        //{{ addShortcodeForm

        /**
         * Add shortcode form
         *
         * @return void
         */
        public static function addShortcodeForm()
        {
            global $ipmtube_useEditor;

            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');

            if ( $ipmtube_useEditor ) {
                $viewer = new IPMTube_Viewer();
                $viewer->shortcodeBackend();
            }
        }

        //}}
        //{{ shortcode

        /**
         * Get shortcode
         *
         * @param  array  $atts
         * @param  string $content
         * @return void
         */
        public static function shortcode( $atts, $content = '')
        {
            $viewer = new IPMTube_Viewer();
            return $viewer->shortcode( $atts, $content );
        }

        //}}
        //{{ adminStyle

        /**
         * Add Css file
         *
         * @return void
         */
        public static function adminStyle()
        {
            wp_deregister_style( 'ipmtube-admin-style' );
            wp_register_style('ipmtube-admin-style', IPMTUBE_BASE_URL . 'assets/css/admin.min.css', false, null);
            wp_enqueue_style('ipmtube-admin-style');
        }

        //}}
        //{{ adminGlobalStyle

        /**
         * Add Css file to all pages
         *
         * @return void
         */
        public static function adminGlobalStyle()
        {
            wp_deregister_style( 'ipmtube-admin-global-style' );
            wp_register_style('ipmtube-admin-global-style', IPMTUBE_BASE_URL . 'assets/css/admin-global.min.css', false, null);
            wp_enqueue_style('ipmtube-admin-global-style');
        }

        //}}
        //{{ adminScript

        /**
         * Add javascript file
         *
         * @return void
         */
        public static function adminScript()
        {
        ?>
            <script type="text/javascript">
                var intm_img_url   = '<?php echo IPMTUBE_BASE_URL . 'img/'; ?>',
                    ui_base_image  = '<?php echo IPMTUBE_BASE_URL . 'assets/img/'; ?>',
                    ui_message     =
                    {
                        delete_confirm_title: '<?php _e( 'Delete Confirmation', IPMTUBE_SLUG ); ?>',
                        delete_confirm_info: '<?php _e( 'Are you sure doing this action?', IPMTUBE_SLUG ); ?>'
                    }
            </script>
        <?php
            wp_deregister_script('ipmtube-admin-script');
            wp_enqueue_script(
                'ipmtube-admin-script',
                IPMTUBE_BASE_URL . 'assets/js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        //}}
        //{{ adminGlobalScript

        /**
         * Add javascript file to all pages
         *
         * @return void
         */
        public static function adminGlobalScript()
        {
            wp_deregister_script('ipmtube-admin-global-script');
            wp_enqueue_script(
                'ipmtube-admin-global-script',
                IPMTUBE_BASE_URL . 'assets/js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        //}}
        //{{ publicStyle

        /**
         * Print public style
         *
         * @return void
         */
        public static function publicStyle()
        {
        ?>
            <script type="text/javascript">
                var ipmtube_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo IPMTUBE_BASE_URL; ?>assets/css/public.min.css" rel="stylesheet">
        <?php
        }

        //}}
        //{{ publicFooterScript

        /**
         * Print script in footer
         *
         * @return void
         */
        public static function publicFooterScript()
        {
        ?>
            <script>
                //
                //Insert youtube api script
                var tag = document.createElement('script');
                tag.src = "https://www.youtube.com/iframe_api";
                var firstScriptTag = document.getElementsByTagName('script')[0];
                firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);

                //
                //Create player iframe
                function onYouTubeIframeAPIReady()
                {
                  jQuery( '.ipmtube-player' ).each( function()
                  {
                      var object   = jQuery(this);
                      var objectId = object.attr( 'id' );
                      var videoId  = object.data( 'id' );
                      var height   = object.data( 'height' );
                      var width    = object.data( 'width' );
                      var auto     = object.data( 'autoplay' );
                      var start    = object.data( 'start' );

                      player = new YT.Player(objectId, {
                          height: height,
                          width: width,
                          videoId: videoId,
                          autoplay: auto,
                          start: start,
                          events: {
                            'onReady': onYTPlayerReady,
                            'onStateChange': onYTPlayerStateChange
                          }
                      });
                  });
                }

                function onYTPlayerReady(event)
                {
                    var iframe   = event.target.getIframe();
                    var autoplay = jQuery(iframe).data( 'autoplay' );
                    var start    = jQuery(iframe).data( 'start' );
                    if ( autoplay == 1 ) {
                        if ( start != 0 ) {
                            event.target.seekTo( start );
                        }
                        event.target.playVideo();
                    }
                }

                function onYTPlayerStateChange(event)
                {
                    var iframe = event.target.getIframe();
                    var isDone = jQuery( iframe ).data( 'donePlaying' );
                    var start  = jQuery(iframe).data( 'start' );
                    if (event.data == YT.PlayerState.PLAYING && isDone != 1 )
                    {
                        if ( start != 0 ) {
                            event.target.seekTo( start );
                        }
                        jQuery( iframe ).data( 'donePlaying', 1 );
                        //
                        //Save stat
                        var pageId = jQuery( iframe ).attr( 'id' ).replace( 'ipmtube-player-', '' );

                        jQuery.ajax({
                            url: ipmtube_ajaxurl+'?doajax=1&ipmtube=1&action=savestat',
                            type: "POST",
                            data: 'page_id='+pageId+'&type=view',
                            dataType: "json",
                            success: function ( result ) {}
                        });
                    }
                }
            </script>
        <?php
        }

        //}}
        //{{ publicScript

        /**
         * Print public script
         *
         * @return void
         */
        public static function publicScript()
        {
            wp_enqueue_script('jquery');

            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');

            wp_deregister_script('ipmtube-public-script');
            wp_enqueue_script(
                'ipbar-public-script',
                IPMTUBE_BASE_URL . 'assets/js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        //}}
    }
}
