<?php
/**
 * Controller to handling updating video process
 *
 * @package wp-tube-profit-wiz
 * @author Chris Jenkins
 * @link http://pluginsforyou.com/
 */

if ( ! class_exists( 'IPMTube_Ajax_Update' ))
{
    class IPMTube_Ajax_Update
    {
        /**
         * Execution save options process
         *
         * @return void
         */
        public function exec()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['video_id'] )) {
                $videoId = absint( $_POST['video_id'] );
                if ( $video = get_post( $videoId ) ) {
                    $this->_updateVideo( $video );
                } else {
                    $videoId = 0;
                }
            } else {
                $videoId = $this->_addVideo();
            }
            if ( $videoId )
            {
                $error = false;
                $model = new IPMTube_Model();
                $model->saveSetting( $videoId );
            }
            if ( $error ) {
                $status   = 0;
                $videoId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed create video.', IPMTUBE_SLUG );
                } else {
                    $message = __( 'Failed save video.', IPMTUBE_SLUG );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully created video.', IPMTUBE_SLUG );
                    $redirect = admin_url() . 'admin.php?page=wptubeprofitwiz&action=edit&id=' . $videoId . '&create=1&tab=ipmtube-section-design';
                } else {
                    $message = __( 'Successfully saved video.', 'wp_video_page_creator' );
                }
            }
            $result = array(
                'status'    => $status,
                'message'   => $message,
                'videoid'   => $videoId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }

        /**
         * Add new video
         *
         * @return int
         */
        protected function _addVideo()
        {
            global $user_ID;

            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status,
                'post_type'    => 'ipmtube-item',
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }

        /**
         * Update video
         *
         * @param  object $video
         * @return boolean
         */
        protected function _updateVideo( $video )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $video->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $video->post_status ) {
                $dataPost['post_status'] = $status;
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $video->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
    }
}
