<?php
if ( ! class_exists( 'IPMTube_Viewer' ))
{
    /**
     * Viewer class
     *
     * @package wp-tube-profit-wiz
     * @author Chris Jenkins
     * @link http://pluginsforyou.com/
     */

    class IPMTube_Viewer
    {
        //{{ dashboard

        /**
         * Manage page viewer
         *
         * @return void
         */
        public function dashboard()
        {
            //Render view
            $this->view( 'manage/dashboard' );
        }

        //}}
        //{{ addnew

        /**
         * Add new page viewer
         *
         * @return void
         */
        public function addnew()
        {
            $this->manage();
        }

        //}}
        //{{ edit

        /**
         * Edit page viewer
         *
         * @return void
         */
        public function edit()
        {
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPMTUBE_SLUG ) );
            }
            $id = absint( $_GET['id'] );
            if ( ! $video = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPMTUBE_SLUG ) );
            }
            $this->manage( $video );
        }

        //}}
        //{{ manage

        /**
         * Manage page viewer
         *
         * @param object $video
         * @return void
         */
        public function manage( $video = false )
        {
            //
            //Including script
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');

            $videoId = 0;
            if ( $video ) {
                $videoId = $video->ID;
            }
            $setting     = new IPMTube_Setting( $videoId, '__ipmtube-setting' );
            $form_action = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipmtube=1&action=ipmtube_update';

            if ( $video )
            {
                $pageTitle   = __( 'Edit Video', IPMTUBE_SLUG );
                $submitLabel = __( 'Save Change', IPMTUBE_SLUG );
                $submitId    = 'ipmtube-edit-video';
                $formId      = 'ipmtube-form-update';
                $submitIcon  = 'floppy-o';
                $pageId      = 'wptubeprofitwiz';

            } else
            {
                $pageTitle   = __( 'Add Video', IPMTUBE_SLUG );
                $submitLabel = __( 'Add Video', IPMTUBE_SLUG );
                $submitId    = 'ipmtube-add-video';
                $formId      = 'ipmtube-form-add';
                $submitIcon  = 'plus-circle';
                $pageId      = 'wptubeprofitwiz-addnew';
            }
            $this->pageId      = $pageId;
            $this->pageTitle   = $pageTitle;
            $this->submitLabel = $submitLabel;
            $this->submitId    = $submitId;
            $this->formId      = $formId;
            $this->submitIcon  = $submitIcon;
            $this->setting     = $setting;
            $this->video       = $video;
            $this->videoId     = $videoId;

            $tab = 'ipmtube-section-general';
            if ( ! empty( $_REQUEST['tab'] )) {
                $tab = $_REQUEST['tab'];
            }
            $this->tab = $tab;

            //Render view
            $this->view( 'manage/main' );
        }

        //}}
        //{{ shortcodeBackend

        /**
         * Shortcode Backend viewer
         *
         * @return void
         */
        public function shortcodeBackend()
        {
            //Render view
            $this->view( 'shortcode/backend/main' );
        }

        //}}
        //{{ shortcode

        /**
         * Shortcode frontend viewer
         *
         * @param array $atts
         * @return void
         */
        public function shortcode( $atts )
        {
              global $user_ID;

              if ( empty( $atts['video'] )) {
                  return '';
              }
              //
              //Get content
              $videoId = absint( $atts['video'] );
              if ( ! $video = get_post( $videoId )) {
                  return '';
              }
              //
              //Check post status
              if ( $video->post_status != 'publish' ) {
                  return '';
              }
              $this->video   = $video;
              $this->setting = new IPMTube_Setting( $videoId, '__ipmtube-setting' );
              $this->args    = $atts;

              //
              //Include view
              ob_start();
              $this->view( 'shortcode/frontend/mtube' );
              $output  = ob_get_contents();
              ob_end_clean();
              return $output;
        }

        //}}
        //{{ fixYoutubeUrl

        /**
         * Fix youtube url
         *
         * @param  string $url
         * @return string
         */
        public function fixYoutubeUrl( $url )
        {
            if ( $url )
            {
                if ( strpos( $url, 'embed' ) === false ) {
                    if ( strpos( $url, 'watch' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['query'] )) {
                            parse_str( $parsed['query'], $args );
                            if ( ! empty( $args['v'] )) {
                                $id = $args['v'];
                            }
                        }
                        $url = 'http://youtube.com/embed/' . $id;

                    } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['path'] )) {
                            $id = trim( $parsed['path'], '/' );
                        }
                        $url = 'http://youtube.com/embed/' . $id;

                    }
                }
                $url .= '?rel=0';
            }
            return $url;
        }

        //}}
        //{{ getVideoId

        /**
         * Get video id
         *
         * @param  string $url
         * @return string
         */
        public function getVideoId( $url )
        {
            $id = '';
            if ( strpos( $url, 'embed' ) === false ) {
                if ( strpos( $url, 'watch' ) !== false ) {
                    $parsed = parse_url( $url );
                    if ( ! empty( $parsed['query'] )) {
                        parse_str( $parsed['query'], $args );
                        if ( ! empty( $args['v'] )) {
                            $id = $args['v'];
                        }
                    }
                } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                    $parsed = parse_url( $url );
                    if ( ! empty( $parsed['path'] )) {
                        $id = trim( $parsed['path'], '/' );
                    }
                }
            } else {
                $parsed = parse_url( $url );
                if ( ! empty( $parsed['path'] )) {
                    $id = str_replace( 'embed/', '', $parsed['path'] );
                }
            }
            return $id;
        }

        //}}
        //{{ view

        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPMTUBE_VIEW;
            $path .= strtolower( $filename ) . '.php';
            if ( file_exists( $path )) {
                include( $path );
            }
        }

        //}}
    }
}
